---------------------
Django: Sane Testing
---------------------

Welcome to library that allows you to really test your Django applications. Read :ref:`introduction <intro>` if you're intrested in my motivations and an overview of what this library do; look at :ref:`test introduction <test-intro>` if you want to know my approach to web testing (fundamental to project design) or proceed directly to :ref:`Usage <usage>` to start using it, or :ref:`plugin description <plugins>` if you're experienced testing/nose coder and just want the plugin reference.

Trac is available at `my devel pages <http://devel.almad.net/trac/django-sane-testing/>`_ and downloads available from `releases <http://devel.almad.net/trac/django-sane-testing/wiki/Releases>`_. Those interested can also always grab code directly from `repository <http://devel.almad.net/hg/django-sane-testing/>`_ or `track project at ohloh <http://www.ohloh.net/p/django-sane-testing>`_.

Feedback is always appreciated. Send it to bugs at almad.net, I'll be glad to hear from you.

Published under `BSD license <http://www.opensource.org/licenses/bsd-license.php>`_; do what you want, just test it.

.. toctree::
   :maxdepth: 2

   intro
   test-intro
   usage
   wrap-up

